summaryrefslogtreecommitdiff
path: root/examples/vf6xx_colibri_m4/demo_apps/rpmsg/str_echo/rpmsg_str_echo.c
diff options
context:
space:
mode:
Diffstat (limited to 'examples/vf6xx_colibri_m4/demo_apps/rpmsg/str_echo/rpmsg_str_echo.c')
-rw-r--r--examples/vf6xx_colibri_m4/demo_apps/rpmsg/str_echo/rpmsg_str_echo.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/vf6xx_colibri_m4/demo_apps/rpmsg/str_echo/rpmsg_str_echo.c b/examples/vf6xx_colibri_m4/demo_apps/rpmsg/str_echo/rpmsg_str_echo.c
index 9d4cdae..4c7847d 100644
--- a/examples/vf6xx_colibri_m4/demo_apps/rpmsg/str_echo/rpmsg_str_echo.c
+++ b/examples/vf6xx_colibri_m4/demo_apps/rpmsg/str_echo/rpmsg_str_echo.c
@@ -113,7 +113,7 @@ void StrEchoTask(void *pvParameters)
/*
* pingpong demo loop
*/
for (;;) {
xSemaphoreTake(app_sema, portMAX_DELAY);
@@ -146,7 +146,7 @@ int main(void)
vf6xx_DbgConsole_Init(UART2, ccmIpgBusClk, 115200);
- printf("Starting RPMSG PingPong Demo...\r\n");
+ printf("Starting RPMSG String Echo Demo...\r\n");
/*
* Prepare for the MSCM Interrupt
@@ -113,7 +113,7 @@ void StrEchoTask(void *pvParameters)
/*
- * pingpong demo loop
+ * String Echo demo loop
*/
for (;;) {